@@ -420,6 +420,7 @@ static void
 gtk_source_gutter_dispose (GObject *object)
 {
 	GtkSourceGutter *gutter = (GtkSourceGutter *)object;
+	GtkWidget *child;
 
 	g_clear_pointer (&gutter->target_binding, g_binding_unbind);
 
@@ -429,6 +430,11 @@ gtk_source_gutter_dispose (GObject *object)
 		g_clear_object (&gutter->signals);
 	}
 
+	while ((child = gtk_widget_get_first_child (GTK_WIDGET (gutter))))
+	{
+		gtk_widget_unparent (child);
+	}
+
 	G_OBJECT_CLASS (gtk_source_gutter_parent_class)->dispose (object);
 }
 
@@ -881,7 +887,7 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 	gtk_snapshot_push_clip (snapshot,
 	                        &GRAPHENE_RECT_INIT (0,
 	                                             0,
-						     clip_width,
+                                                     clip_width,
 	                                             gtk_widget_get_height (widget)));
 
 	/* Now let the renderers draw the content for each line. Because
