@@ -29,8 +29,6 @@
 #include <gtksourceview/vim/gtksourcevimregisters.h>
 #include <gtksourceview/vim/gtksourcevimstate.h>
 
-#include "gtksourceview/gtksourcelanguagemanager-private.h"
-
 static void
 run_test (const char *text,
           const char *input,
@@ -97,8 +95,8 @@ run_test (const char *text,
 	g_assert_cmpstr (ret, ==, expected);
 	g_free (ret);
 
-	g_assert_finalize_object (G_OBJECT (vim));
-	g_assert_finalize_object (G_OBJECT (view));
+	g_object_unref (vim);
+	g_object_unref (view);
 }
 
 static void
@@ -246,7 +244,6 @@ main (int argc,
 	const char *srcdir = g_getenv ("G_TEST_SRCDIR");
 	char *schemes_search_path[2] = { NULL };
 	GtkSourceStyleSchemeManager *schemes;
-	char *rng;
 	int ret;
 
 	g_assert_true (g_file_test (srcdir, G_FILE_TEST_IS_DIR));
@@ -254,10 +251,6 @@ main (int argc,
 	gtk_init ();
 	gtk_source_init ();
 
-	rng = g_build_filename (TOP_SRCDIR, "data", "language-specs", "language2.rng", NULL);
-	_gtk_source_language_manager_set_rng_file (rng);
-	g_free (rng);
-
 	schemes = gtk_source_style_scheme_manager_get_default ();
 	schemes_search_path[0] = g_build_filename (srcdir, "..", "data", "styles", NULL);
 	gtk_source_style_scheme_manager_set_search_path (schemes, (const char * const *)schemes_search_path);
